@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,12 +43,33 @@
 
 #define YELP_FACTORY_OAFIID "OAFIID:GNOME_Yelp_Factory"
 
-static BonoboObject * yelp_base_factory       (BonoboGenericFactory *factory,
+poptContext  poptCon;
+gint         next_opt;
+
+/*structure defining command line option.*/
+
+struct poptOption options[] = {
+	{
+		"url",
+		'u',
+		POPT_ARG_STRING,
+		NULL,
+		1,
+		NULL,
+		NULL,
+	},
+	NULL
+};
+
+static BonoboObject * main_base_factory       (BonoboGenericFactory *factory,
 					       const gchar          *iid,
 					       gpointer              closure);
-static CORBA_Object   yelp_main_activate_base (void);
-static gboolean       yelp_main_idle_start    (gchar                *url);
-static int            yelp_save_session       (GnomeClient          *client,
+static CORBA_Object   main_activate_base      (void);
+static void           main_open_new_window    (CORBA_Object          yelp_base,
+					       const gchar          *url);
+static void           main_start              (gchar                *url);
+static gboolean       main_idle_start         (gchar                *url);
+static int            main_save_session       (GnomeClient          *client,
 					       gint                  phase,
 					       GnomeRestartStyle     rstyle,
 					       gint                  shutdown,
@@ -56,12 +77,14 @@ static int            yelp_save_session       (GnomeClient          *client,
 					       gint                  fast,
 					       gpointer              cdata);
 
-static gint           yelp_client_die         (GnomeClient          *client, 
+static void           main_client_die         (GnomeClient          *client, 
 					       gpointer              cdata);
 
+static gboolean	      main_restore_session    (void);
+
 
 static BonoboObject *
-yelp_base_factory (BonoboGenericFactory *factory,
+main_base_factory (BonoboGenericFactory *factory,
 		   const gchar          *iid,
 		   gpointer              closure)
 {
@@ -77,7 +100,7 @@ yelp_base_factory (BonoboGenericFactory *factory,
 }
 
 static CORBA_Object
-yelp_main_activate_base ()
+main_activate_base ()
 {
 	CORBA_Environment ev;
 	CORBA_Object      yelp_base;
@@ -98,7 +121,7 @@ yelp_main_activate_base ()
 }
 
 static void
-yelp_main_open_new_window (CORBA_Object yelp_base, const gchar *url)
+main_open_new_window (CORBA_Object yelp_base, const gchar *url)
 {
 	CORBA_Environment ev;
 	
@@ -114,17 +137,17 @@ yelp_main_open_new_window (CORBA_Object yelp_base, const gchar *url)
 }
 	
 static void
-yelp_main_start (gchar *url) 
+main_start (gchar *url) 
 {
 	CORBA_Object yelp_base;
 	
-	yelp_base = yelp_main_activate_base ();
+	yelp_base = main_activate_base ();
 
 	if (!yelp_base) {
 		g_error ("Couldn't activate YelpBase");
 	}
 	
-	yelp_main_open_new_window (yelp_base, url);
+	main_open_new_window (yelp_base, url);
 	
 	bonobo_object_release_unref (yelp_base, NULL);
 
@@ -134,17 +157,17 @@ yelp_main_start (gchar *url)
 }
 
 static gboolean
-yelp_main_idle_start (gchar *url)
+main_idle_start (gchar *url)
 {
 	CORBA_Object yelp_base;
 	
-	yelp_base = yelp_main_activate_base ();
+	yelp_base = main_activate_base ();
 
 	if (!yelp_base) {
 		g_error ("Couldn't activate YelpBase");
 	}
 
-	yelp_main_open_new_window (yelp_base, url);
+	main_open_new_window (yelp_base, url);
 
 	if (url) {
 		g_free (url);
@@ -155,7 +178,7 @@ yelp_main_idle_start (gchar *url)
 
 
 static gint 
-yelp_save_session (GnomeClient        *client,
+main_save_session (GnomeClient        *client,
                    gint                phase,
                    GnomeRestartStyle   rstyle,
                    gint                shutdown,
@@ -163,20 +186,75 @@ yelp_save_session (GnomeClient        *client,
                    gint                fast,
                    gpointer            cdata) 
 {
+	
+	GNOME_Yelp_WindowList  *list;
+	CORBA_Environment       ev;
+	CORBA_Object            yelp_base;
+	gchar                 **argv;
+	gint                    i=1;
+	gint                    temp;
 
-        gchar *argv[]= { NULL };
+	CORBA_exception_init (&ev);
 
-        argv[0] = (gchar*) cdata;
-        gnome_client_set_clone_command (client, 1, argv);
-        gnome_client_set_restart_command (client, 1, argv);
-        return TRUE;
+	yelp_base = main_activate_base ();
+
+	list = GNOME_Yelp_getWindows (yelp_base, &ev);
+
+	bonobo_object_release_unref (yelp_base, NULL);
+
+	temp = list->_length;
+	
+	temp = temp + 1;
+
+	argv = g_malloc0 (sizeof (gchar *) * temp);
+
+	argv[0] = (gchar*) cdata;
+       
+	/* Get the URI of each window */
+
+	for (i=0 ;i < list->_length; i++) {
+                argv[i+1] = g_strconcat ("--url=", list->_buffer[i], NULL);
+        }
+
+	gnome_client_set_clone_command (client, temp, argv);
+	gnome_client_set_restart_command (client, temp, argv);
+
+	g_free (argv);
+
+	return TRUE;
 }
 
-static gint 
-yelp_client_die (GnomeClient *client, 
+static void
+main_client_die (GnomeClient *client, 
 		 gpointer     cdata)
 {
-        exit (0);
+	bonobo_main_quit ();
+}
+
+static gboolean
+main_restore_session (void)
+{
+	CORBA_Object yelp_base;
+
+	yelp_base = main_activate_base ();
+
+        if (!yelp_base) {
+                g_error ("Couldn't activate YelpBase");
+        }
+
+	/*Get the argument of commandline option*/
+
+	while( (next_opt = poptGetNextOpt (poptCon)) > 0) {
+        	if ( next_opt == 1) {
+                	gchar *url = (gchar *) poptGetOptArg (poptCon);
+                	main_open_new_window (yelp_base, url);
+                	if (url) {
+                        	g_free (url);
+                        }
+                }
+        }
+
+	return TRUE;
 }
 
 int
@@ -186,6 +264,7 @@ main (int argc, char **argv)
 	CORBA_Object  factory;
 	gchar        *url = NULL;
 	GnomeClient  *client;
+	gboolean      flag = FALSE;
 	
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);  
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -205,30 +284,48 @@ main (int argc, char **argv)
 				      NULL);
 
 	gnome_vfs_init ();
+	
+	/*Commandline parsing is done here*/
+
+	poptCon = poptGetContext (PACKAGE, argc, (const gchar **) argv, options, 0);
 
 	client = gnome_master_client ();
         g_signal_connect (client, "save_yourself",
-                          G_CALLBACK (yelp_save_session), (gpointer) argv[0]);
+                          G_CALLBACK (main_save_session), (gpointer) argv[0]);
         g_signal_connect (client, "die",
-                          G_CALLBACK (yelp_client_die), NULL);
+                          G_CALLBACK (main_client_die), NULL);
 
 	factory = bonobo_activation_activate_from_id (YELP_FACTORY_OAFIID,
 						      Bonobo_ACTIVATION_FLAG_EXISTING_ONLY, 
 						      NULL, NULL);
 	
+	/*Check for previous session to restore.*/
+
+	if(gnome_client_get_flags (client) & GNOME_CLIENT_RESTORED) {
+		flag = TRUE;
+        }
+
 	if (!factory) {
 		BonoboGenericFactory   *factory;
 		/* Not started, start now */
 
 		factory = bonobo_generic_factory_new (YELP_FACTORY_OAFIID,
-						      yelp_base_factory,
+						      main_base_factory,
 						      NULL);
 
 		bonobo_running_context_auto_exit_unref (BONOBO_OBJECT (factory));
-		g_idle_add ((GSourceFunc) yelp_main_idle_start, url);
+        
+	        /*Depending on the flag, restore the session*/
+
+		if (flag) {
+			g_idle_add ((GSourceFunc) main_restore_session, NULL);
+		} else {
+			g_idle_add ((GSourceFunc) main_idle_start, url);
+		}
+
 		bonobo_main ();
 	} else {
-		yelp_main_start (url);
+		main_start (url);
 	}
 
         return 0;
