@@ -316,7 +316,9 @@ content_reader_finished_cb (YelpReader      *reader,
 			content_tree_selection_changed_cb,
 			view);
  
-		gtk_tree_selection_select_path (selection, path);
+/* 		gtk_tree_selection_select_path (selection, path); */
+		gtk_tree_view_set_cursor (GTK_TREE_VIEW (priv->content_tree),
+					  path, NULL, FALSE);
 		
 		g_signal_handlers_unblock_by_func (
 			selection,
@@ -505,6 +507,7 @@ yelp_view_content_show_uri (YelpViewContent  *content,
 	YelpViewContentPriv *priv;
 	GNode               *node;
 	GdkCursor           *cursor;
+	gboolean 	     reset_focus = FALSE;
 	
 	g_return_if_fail (YELP_IS_VIEW_CONTENT (content));
 	g_return_if_fail (uri != NULL);
@@ -512,10 +515,6 @@ yelp_view_content_show_uri (YelpViewContent  *content,
 	priv = content->priv;
 
 	if (yelp_uri_get_type (uri) == YELP_URI_TYPE_DOCBOOK_XML) {
-		/* ghelp uri-scheme /usr/share/gnome/help... */
-/* 		const gchar *docpath; */
-
-/*  		docpath = yelp_uri_get_path (uri); */
 
 		if (!priv->current_uri || 
 		    !yelp_uri_equal_path (uri, priv->current_uri)) {
@@ -528,13 +527,26 @@ yelp_view_content_show_uri (YelpViewContent  *content,
 				yelp_view_content_set_tree (content, node);
 				
 			} else {
+				if (gtk_widget_is_focus (priv->tree_sw)) {
+					reset_focus = TRUE;
+				}
+
 				gtk_widget_hide (priv->tree_sw);
 			}
 		}
 	} else {
+		if (gtk_widget_is_focus (priv->tree_sw)) {
+			reset_focus = TRUE;
+		}
+
 		gtk_widget_hide (priv->tree_sw);
 		
 	}
+
+	if (reset_focus) {
+		gtk_widget_child_focus (GTK_WIDGET (content), 
+					GTK_DIR_TAB_FORWARD);
+	}
 	
 	priv->first = TRUE;
 	
@@ -557,7 +569,7 @@ yelp_view_content_show_uri (YelpViewContent  *content,
 		yelp_html_clear (priv->html_view);
 
 		yelp_html_printf (priv->html_view, 
-				  "<html><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><title>..</title><body bgcolor=\"white\"><center>%s</center></body></html>", 
+				  "<html><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><title>..</title><body><center>%s</center></body></html>", 
 				  loading);
 		yelp_html_close (priv->html_view);
 	}
