@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,7 +25,9 @@
 
 #include <gtk/gtkwindow.h>
 #include <gtk/gtktreemodel.h>
+
 #include "yelp-base.h"
+#include "yelp-uri.h"
 
 #define YELP_TYPE_WINDOW		(yelp_window_get_type ())
 #define YELP_WINDOW(obj)		(GTK_CHECK_CAST ((obj), YELP_TYPE_WINDOW, YelpWindow))
@@ -58,6 +60,6 @@ GtkWidget *      yelp_window_new             (GNode         *doc_tree,
 
 void             yelp_window_open_uri        (YelpWindow    *window,
 					      const gchar   *str_uri);
-const gchar *    yelp_window_get_current_uri (YelpWindow    *window);
+YelpURI *        yelp_window_get_current_uri (YelpWindow    *window);
 
 #endif /* __YELP_WINDOW_H__ */
